@@ -1,7 +1,8 @@
 import threading
 from spackle.customer import Customer
 from spackle.exceptions import SpackleException
-from spackle.stores import DynamoDBStore
+from spackle.stores import DynamoDBStore, MemoryStore
+from spackle.constants import FEATURE_TYPE_FLAG, FEATURE_TYPE_LIMIT
 
 api_key = None
 api_base = "https://api.spackle.so/v1"
